@@ -218,18 +218,19 @@ _gtk_text_buffer_insert_markup (GtkTextBuffer *buffer, GtkTextIter *iter, const
 gboolean
 gpk_window_set_size_request (GtkWindow *window, guint width, guint height)
 {
-#ifdef PK_BUILD_SMALL_FORM_FACTOR
 	GdkScreen *screen;
 	guint screen_w;
 	guint screen_h;
-	guint percent_w;
-	guint percent_h;
 
 	/* check for tiny screen, like for instance a OLPC or EEE */
 	screen = gdk_screen_get_default ();
 	screen_w = gdk_screen_get_width (screen);
 	screen_h = gdk_screen_get_height (screen);
 
+#ifdef PK_BUILD_SMALL_FORM_FACTOR
+	guint percent_w;
+	guint percent_h;
+
 	/* find percentage of screen area */
 	percent_w = (width * 100) / screen_w;
 	percent_h = (height * 100) / screen_h;
@@ -250,7 +251,11 @@ gpk_window_set_size_request (GtkWindow *window, guint width, guint height)
 #endif
 	/* normal size laptop panel */
 	g_debug ("using native mode: %ix%i", width, height);
-	gtk_window_set_default_size (window, width, height);
+
+	if (getenv ("WAYLAND_DISPLAY"))
+		gtk_window_set_default_size (window, width > screen_w ? screen_w : width, height > screen_h ? screen_h - 100 : height);
+	else
+		gtk_window_set_default_size (window, width, height);
 	small_form_factor_mode = FALSE;
 out:
 	return !small_form_factor_mode;
@@ -327,9 +332,10 @@ gpk_package_id_format_twoline (GtkStyleContext *style,
 	g_return_val_if_fail (package_id != NULL, NULL);
 
 	/* get style color */
+	//style = NULL; //!!!!!
 	if (style != NULL) {
 		gtk_style_context_get_color (style,
-					     GTK_STATE_FLAG_INSENSITIVE,
+					     GTK_STATE_FLAG_PRELIGHT,
 					     &inactive);
 		color = g_strdup_printf ("#%02x%02x%02x",
 					 (guint) (inactive.red * 255.0f),
